import * as cdk from "aws-cdk-lib";
import * as constructs from "constructs";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 *
 * @schema CfnDataLakePipelineProps
 */
export interface CfnDataLakePipelineProps {
    /**
     * Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used
     *
     * @schema CfnDataLakePipelineProps#Profile
     */
    readonly profile?: string;
    /**
     * Unique 24-hexadecimal digit string that identifies your project.
     *
     * @schema CfnDataLakePipelineProps#ProjectId
     */
    readonly projectId: string;
    /**
     * State of the Data Lake Pipeline.
     *
     * @schema CfnDataLakePipelineProps#State
     */
    readonly state?: string;
    /**
     * Name of this Data Lake Pipeline.
     *
     * @schema CfnDataLakePipelineProps#Name
     */
    readonly name: string;
    /**
     * @schema CfnDataLakePipelineProps#Sink
     */
    readonly sink: Sink;
    /**
     * @schema CfnDataLakePipelineProps#Source
     */
    readonly source?: Source;
    /**
     * Ingestion destination of a Data Lake Pipeline.
     *
     * @schema CfnDataLakePipelineProps#Transformations
     */
    readonly transformations: Transformations[];
}
/**
 * Converts an object of type 'CfnDataLakePipelineProps' to JSON representation.
 */
export declare function toJson_CfnDataLakePipelineProps(obj: CfnDataLakePipelineProps | undefined): Record<string, any> | undefined;
/**
 * Ingestion destination of a Data Lake Pipeline.
 *
 * @schema sink
 */
export interface Sink {
    /**
     * Type of ingestion destination of this Data Lake Pipeline.
     *
     * @schema sink#Type
     */
    readonly type?: SinkType;
    /**
     * Target cloud provider for this Data Lake Pipeline.
     *
     * @schema sink#MetadataProvider
     */
    readonly metadataProvider?: string;
    /**
     * Target cloud provider region for this Data Lake Pipeline.
     *
     * @schema sink#MetadataRegion
     */
    readonly metadataRegion?: string;
    /**
     * Ordered fields used to physically organize data in the destination.
     *
     * @schema sink#PartitionFields
     */
    readonly partitionFields?: PartitionFields[];
}
/**
 * Converts an object of type 'Sink' to JSON representation.
 */
export declare function toJson_Sink(obj: Sink | undefined): Record<string, any> | undefined;
/**
 * Ingestion destination of a Data Lake Pipeline.
 *
 * @schema source
 */
export interface Source {
    /**
     * Type of ingestion source of this Data Lake Pipeline.
     *
     * @schema source#Type
     */
    readonly type?: SourceType;
    /**
     * Human-readable name that identifies the cluster.
     *
     * @schema source#ClusterName
     */
    readonly clusterName?: string;
    /**
     * Human-readable name that identifies the collection.
     *
     * @schema source#CollectionName
     */
    readonly collectionName?: string;
    /**
     * Human-readable name that identifies the database.
     *
     * @schema source#DatabaseName
     */
    readonly databaseName?: string;
    /**
     * Unique 24-hexadecimal character string that identifies the project.
     *
     * @schema source#GroupId
     */
    readonly groupId?: string;
}
/**
 * Converts an object of type 'Source' to JSON representation.
 */
export declare function toJson_Source(obj: Source | undefined): Record<string, any> | undefined;
/**
 * Ordered fields used to physically organize data in the destination.
 *
 * @schema transformations
 */
export interface Transformations {
    /**
     * Key in the document.
     *
     * @schema transformations#Field
     */
    readonly field?: string;
    /**
     * Type of transformation applied during the export of the namespace in a Data Lake Pipeline.
     *
     * @schema transformations#Type
     */
    readonly type?: string;
}
/**
 * Converts an object of type 'Transformations' to JSON representation.
 */
export declare function toJson_Transformations(obj: Transformations | undefined): Record<string, any> | undefined;
/**
 * Type of ingestion destination of this Data Lake Pipeline.
 *
 * @schema SinkType
 */
export declare enum SinkType {
    /** DLS */
    DLS = "DLS"
}
/**
 * Ordered fields used to physically organize data in the destination.
 *
 * @schema partitionFields
 */
export interface PartitionFields {
    /**
     * Human-readable label that identifies the field name used to partition data.
     *
     * @schema partitionFields#FieldName
     */
    readonly fieldName?: string;
    /**
     * Sequence in which MongoDB Cloud slices the collection data to create partitions. The resource expresses this sequence starting with zero.
     *
     * @schema partitionFields#Order
     */
    readonly order?: number;
}
/**
 * Converts an object of type 'PartitionFields' to JSON representation.
 */
export declare function toJson_PartitionFields(obj: PartitionFields | undefined): Record<string, any> | undefined;
/**
 * Type of ingestion source of this Data Lake Pipeline.
 *
 * @schema SourceType
 */
export declare enum SourceType {
    /** ON_DEMAND_CPS */
    ON_DEMAND_CPS = "ON_DEMAND_CPS",
    /** PERIODIC_CPS */
    PERIODIC_CPS = "PERIODIC_CPS"
}
/**
 * A CloudFormation `MongoDB::Atlas::DataLakePipeline`
 *
 * @cloudformationResource MongoDB::Atlas::DataLakePipeline
 * @stability external
 */
export declare class CfnDataLakePipeline extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::DataLakePipeline";
    /**
     * Resource props.
     */
    readonly props: CfnDataLakePipelineProps;
    /**
     * Attribute `MongoDB::Atlas::DataLakePipeline.CreatedDate`
     */
    readonly attrCreatedDate: string;
    /**
     * Attribute `MongoDB::Atlas::DataLakePipeline.Id`
     */
    readonly attrId: string;
    /**
     * Attribute `MongoDB::Atlas::DataLakePipeline.LastUpdatedDate`
     */
    readonly attrLastUpdatedDate: string;
    /**
     * Create a new `MongoDB::Atlas::DataLakePipeline`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDataLakePipelineProps);
}
